.. mockturtle documentation master file, created by
   sphinx-quickstart on Thu Nov 30 18:28:14 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mockturtle's documentation!
======================================

.. toctree::
   :maxdepth: 2

   getting_started
   debugging
   changelog
   acknowledgments

.. toctree::
   :maxdepth: 2
   :caption: Standard library

   philosophy
   network
   implementations
   sequential
   views
   events

.. toctree::
   :maxdepth: 2
   :glob:
   :caption: Algorithms

   algorithms/index_*

.. toctree::
   :maxdepth: 2
   :glob:
   :caption: Input/Output

   io/*

.. toctree::
   :maxdepth: 2
   :glob:
   :caption: Generators

   generators/*

.. toctree::
   :maxdepth: 2
   :caption: Properties

   properties

.. toctree::
   :maxdepth: 2
   :glob:
   :caption: Utilities

   utils/*

